@@ -17,10 +17,11 @@ import numpy as np
 import pytorch_lightning as pl
 import torch
 import torch.nn.functional as F
-from torch import nn
 
 # power_perceiver imports
-from power_perceiver.consts import BatchKey
+from ocf_datapipes.utils.consts import BatchKey
+from torch import nn
+
 from power_perceiver.hub import NowcastingModelHubMixin
 from power_perceiver.production.pvrnn import N_PV_SYSTEMS_PER_EXAMPLE, PVRNN
 from power_perceiver.production.satellite_transformer import (
@@ -133,6 +134,19 @@ class FullModel(pl.LightningModule, NowcastingModelHubMixin):
         # Predict future satellite images:
         self.satellite_predictor = SatellitePredictor()
 
+        # Load SatellitePredictor weights
+        # self.satellite_predictor.load_state_dict(
+        #    torch.load(
+        #        (
+        #            "/home/jack/dev/ocf/power_perceiver/power_perceiver/experiments/power_perceiver/3qvkf1dy/checkpoints/epoch=170-step=175104-just-satellite-predictor.state_dict.pth"
+        #        )
+        #        if ON_DONATELLO
+        #        else (
+        #            "/home/jack/model_params/satellite_predictor/epoch=170-step=175104-just-satellite-predictor.state_dict.pth"
+        #        )
+        #    )
+        # )
+
         # Infer GSP and PV power output for a single timestep of satellite imagery.
         self.satellite_transformer = SatelliteTransformer()
 
@@ -455,9 +469,9 @@ class FullModel(pl.LightningModule, NowcastingModelHubMixin):
         return [optimizer], [scheduler]
 
     def load_model(
-            self,
-            local_filename: Optional[str] = None,
-            use_hf: bool = True,
+        self,
+        local_filename: Optional[str] = None,
+        use_hf: bool = True,
     ):
         """
         Load model weights
@@ -472,4 +486,4 @@ class FullModel(pl.LightningModule, NowcastingModelHubMixin):
             _log.debug(f"Loading model weights from {local_filename}")
             model = self.load_from_checkpoint(checkpoint_path=local_filename)
             _log.debug("Loading model weights: done")
-            return model
\ No newline at end of file
+            return model
